@@ -1203,10 +1203,18 @@ totem_pl_parser_add_url_valist (TotemPlParser *parser,
 				}
 			}
 
+			/* Remove trailing spaces from titles */
+			if (strcmp (name, "title") == 0) {
+				if (fixed == NULL)
+					fixed = g_strchomp (g_strdup (string));
+				else
+					g_strchomp (fixed);
+			}
+
 			/* Add other values to the metadata hashtable */
 			g_hash_table_insert (metadata,
 					     g_strdup (name),
-					     g_strdup (fixed ? fixed : string));
+					     fixed ? fixed : g_strdup (string));
 		}
 
 		g_value_unset (&value);
@@ -1508,9 +1516,10 @@ totem_pl_parser_parse_internal (TotemPlParser *parser, const char *url,
 		return TOTEM_PL_PARSER_RESULT_UNHANDLED;
 	}
 
-	/* Fix up itpc, see http://www.apple.com/itunes/store/podcaststechspecs.html */
-	if (g_str_has_prefix (url, "itpc") != FALSE) {
-		DEBUG(g_print ("URL '%s' is getting special cased for ITPC parsing\n", url));
+	/* Fix up itpc, see http://www.apple.com/itunes/store/podcaststechspecs.html
+	 * as well as feed:// as used by Firefox */
+	if (g_str_has_prefix (url, "itpc") != FALSE || g_str_has_prefix (url, "feed") != FALSE) {
+		DEBUG(g_print ("URL '%s' is getting special cased for ITPC/FEED parsing\n", url));
 		return totem_pl_parser_add_itpc (parser, url, base, NULL);
 	}
 	/* Try itms Podcast references, see itunes.py in PenguinTV */
@@ -1573,6 +1582,7 @@ totem_pl_parser_parse_internal (TotemPlParser *parser, const char *url,
 			if (strcmp (special_types[i].mimetype, mimetype) == 0) {
 				DEBUG(g_print ("URL '%s' is special type '%s'\n", url, mimetype));
 				if (parser->priv->disable_unsafe != FALSE && special_types[i].unsafe != FALSE) {
+					DEBUG(g_print ("URL '%s' is unsafe so was ignored\n", url));
 					g_free (mimetype);
 					g_free (data);
 					return TOTEM_PL_PARSER_RESULT_IGNORED;
@@ -1829,7 +1839,8 @@ my_gnome_vfs_get_mime_type_for_data (gconstpointer data, int len)
 
 	mimetype = gnome_vfs_get_mime_type_for_data (data, len);
 
-	if (mimetype != NULL && strcmp (mimetype, "text/plain") == 0) {
+	if (mimetype != NULL &&
+	    (strcmp (mimetype, "text/plain") == 0 || strcmp (mimetype, "application/octet-stream") == 0)) {
 		PlaylistIdenCallback func;
 		guint i;
 
@@ -1845,6 +1856,8 @@ my_gnome_vfs_get_mime_type_for_data (gconstpointer data, int len)
 			if (res != NULL)
 				return g_strdup (res);
 		}
+
+		return NULL;
 	}
 
 	return g_strdup (mimetype);
